import { Component } from '@angular/core';
import {DatePipe, NgClass, NgForOf, NgIf} from "@angular/common";
import {FormGroup, FormsModule, NonNullableFormBuilder, ReactiveFormsModule} from "@angular/forms";
import {NzButtonComponent} from "ng-zorro-antd/button";
import {
  NzTableComponent, NzTableModule,
  NzThMeasureDirective
} from "ng-zorro-antd/table";
import {NzColDirective, NzRowDirective} from "ng-zorro-antd/grid";

import {NzFormDirective, NzFormModule} from "ng-zorro-antd/form";
import {NzImageDirective, NzImageModule,} from "ng-zorro-antd/image";
import {NzInputDirective} from "ng-zorro-antd/input";

import {NzOptionComponent, NzSelectComponent} from "ng-zorro-antd/select";
import {NzTreeSelectComponent} from "ng-zorro-antd/tree-select";

import {environment} from "../../../../environments/environment";
import {NzMessageService} from "ng-zorro-antd/message";
import {GoodsService} from "../../../services/goods/goods.service";
import {fallbackImg, orderGoodsStatus} from '../../../data/goods/goods.namespace';
import {GoodsStatusPipe} from "../../../pipes/goods/goods-status.pipe";
import {NzModalModule} from "ng-zorro-antd/modal";
import {OrderGoodsService} from "../../../services/trade/order-goods.service";
import {OrderGoodsStatusPipe} from "../../../pipes/order/order-goods-status.pipe";
import {NzDropDownADirective, NzDropDownDirective, NzDropdownMenuComponent} from "ng-zorro-antd/dropdown";
import {NzMenuDirective, NzMenuItemComponent} from "ng-zorro-antd/menu";
import {NzPopconfirmDirective} from "ng-zorro-antd/popconfirm";
import {OrderGoodsData} from "../../../model/order.interface";
import {NzDividerComponent} from "ng-zorro-antd/divider";
import {NzIconDirective} from "ng-zorro-antd/icon";
import {NzDescriptionsModule} from "ng-zorro-antd/descriptions";
import {NzBadgeComponent} from "ng-zorro-antd/badge";
import {AuditStatusPipe} from "../../../pipes/audit/audit-status.pipe";
import {NzTabComponent, NzTabSetComponent, NzTabsModule} from "ng-zorro-antd/tabs";
import {NzSpinComponent} from "ng-zorro-antd/spin";
import {NzTimelineComponent, NzTimelineItemComponent} from "ng-zorro-antd/timeline";
import {NzResultComponent} from "ng-zorro-antd/result";

@Component({
  selector: 'app-goods-list',
  standalone: true,
  imports: [
    NzColDirective,
    NzRowDirective,
    NzFormDirective,
    ReactiveFormsModule,
    NzTreeSelectComponent,
    NzInputDirective,
    NzSelectComponent,
    NzOptionComponent,
    NzButtonComponent,
    NzTableComponent,
    NzImageModule,
    NzModalModule,
    NzTableModule,
    NzFormModule,
    NzThMeasureDirective,
    NgForOf,
    NzImageDirective,
    GoodsStatusPipe,
    DatePipe,
    OrderGoodsStatusPipe,
    NzDropdownMenuComponent,
    NgIf,
    NzMenuDirective,
    NzDescriptionsModule,
    NzMenuItemComponent,
    NzPopconfirmDirective,
    NzDividerComponent,
    NzDropDownADirective,
    NzDropDownDirective,
    NzTabsModule,
    NzIconDirective,
    NzBadgeComponent,
    AuditStatusPipe,
    NzTabSetComponent,
    FormsModule,
    NzSpinComponent,
    NzTimelineItemComponent,
    NgClass,
    NzResultComponent,
    NzTimelineComponent,

  ],
  templateUrl: './goods-list.component.html',
  styleUrl: './goods-list.component.less'
})
export class GoodsListComponent {
  // 表单页数
  tablePageNum = 1;
  // 表单数据
  tableData: any = {
    total: 0,
    loading: false,
    list: [],
  };
  // 搜索表单
  searchForm: FormGroup;

  baseUrl = environment.baseUrl;
  imageUrl = environment.imageUrl;

  // 商品类型数据
  nodes = [];
  nodesBrand = [];
  orderGoodsData: any;
  orderDetailModal = false;
  isVisible = false;
  orderDetailModalChild = false;
  orderDetailModalLoading = false;
  logisticsNo: any;
  logisticsTraceDetails: any;
  goodsOrderId: any;

  protected readonly fallbackImg = fallbackImg;
  protected readonly orderGoodsStatus = orderGoodsStatus;

  constructor(private fb: NonNullableFormBuilder,
              private msg: NzMessageService,
              private orderGoodsService: OrderGoodsService,
              private goodsService: GoodsService) {


    // 初始化搜索框
    this.searchForm = this.fb.group({
      logisticsNo: [''],
      orderNo: [''],
      goodsType: [''],
      goodsBrand: [''],
      userPhone: [''],
      goodsSpecsName: [''],
      goodsName: [''],
      payType: [''],
      status: [''],
    });


    this.getRequest();
    this.getGoodsTypeNode();
    this.getGoodsBrandNode();

  }

  // 查询列表
  public getRequest(reset: boolean = false) {
    this.tableData.loading  = true;
    if (reset) {
      this.tablePageNum = 1;
    }
    this.searchForm.value.pageNum = this.tablePageNum;
    this.searchForm.value.pageSize = 10;
    this.searchForm.value.time = new Date().getTime();

    this.orderGoodsService.getListGoods(this.searchForm.value , (data: any) => {
      if (data['return_code'] == '000000') {
        this.tableData = data['return_data'];
      } else {
        this.msg.error(data['return_msg']);
      }
      this.tableData.loading  = false;
    });
  }

  // 获取商品分类
  getGoodsTypeNode() {
    this.goodsService.getList({time: new Date().getTime()}, (data: any) => {
      if (data['return_code'] === '000000') {
        this.getNode(data['return_data']);
      }
    });
  }

  // 配置数据
  getNode(array: any): any {
    array.forEach((item: any) => {
      if (item.children) {
        this.getNode(item.children);
      }else {
        item["isLeaf"] = true;
      }
      item["key"] = item.id;

    });
    this.nodes = array;
  }

  // 获取商品品牌
  getGoodsBrandNode() {
    this.goodsService.getListBrandAll( (data: any) => {
      if (data['return_code'] == '000000') {
        this.nodesBrand = data['return_data'];
      }
    });
  }

  getLogisticsNo(id: number): void {
    this.goodsOrderId = id;
    this.isVisible = true;
  }

  showDetail(data: OrderGoodsData): void {
    console.log(data);
    this.orderGoodsData = data;
    this.orderDetailModal  = true;
  }

  handleOk(): void {
    let params =  {
      id: this.goodsOrderId,
      logisticsNo: this.logisticsNo,
      time: new Date().getTime()
    }

    this.orderGoodsService.updateLogisticsNo(params , (data: any) => {
      if (data['return_code'] == '000000') {
        this.isVisible = false;
        this.getRequest(false);
        this.msg.success("成功")
      } else {
        this.msg.error(data['return_msg']);
      }
    });
  }

  showLogisticsNo(id: number): void {
    let params =  {
      id:id,
      time: new Date().getTime()
    }

    this.orderGoodsService.getLogisticsMsg(params , (data: any) => {
      if (data['return_code'] == '000000') {
        this.orderDetailModalChild = true;
        this.logisticsTraceDetails = data['return_data']['logisticsTraceDetails'];
      } else {
        this.msg.error(data['return_msg']);
      }
    });
  }

}
