import { Injectable } from '@angular/core';
import {HttpClient} from "@angular/common/http";
import {environment} from "../../../environments/environment";
import {ObjectData} from "../../utils/objectData.service";

@Injectable({
  providedIn: 'root'
})
export class GoodsService {

  constructor(private http: HttpClient) { }


  /**
   * 编辑商品类型
   * @param params
   * @param callBack
   */
  public editGoodsType(params: object, callBack:any) {
    this.http.post(environment.baseUrl + 'goodsType/editGoodsType', params).subscribe(data => {
      callBack(data);
    });
  }

  /**
   * 查询列表
   * @param params
   * @param callBack
   */
  public getList(params: object, callBack:any) {
    this.http.get(environment.baseUrl + 'goodsType/getList?' + ObjectData.objectByString(params)).subscribe(data => {
      callBack(data);
    });
  }

  /**
   * 删除
   * @param id
   * @param callBack
   */
  public delete(id: number, callBack:any) {
    this.http.get(environment.baseUrl + 'goodsType/delete?id=' + id ).subscribe(data => {
      callBack(data);
    });
  }

  /**
   * 编辑商品品牌
   * @param params
   * @param callBack
   */
  public editGoodsBrand(params: object, callBack:any) {
    this.http.post(environment.baseUrl + 'goodsBrand/editGoodsBrand', params).subscribe(data => {
      callBack(data);
    });
  }

  /**
   * 查询品牌列表
   * @param params
   * @param callBack
   */
  public getListBrand(params: object, callBack:any) {
    this.http.get(environment.baseUrl + 'goodsBrand/getListBrand?' + ObjectData.objectByString(params)).subscribe(data => {
      callBack(data);
    });
  }

  public getListBrandAll(callBack:any) {
    this.http.get(environment.baseUrl + 'goodsBrand/getListBrandAll?time=' + new Date().getTime()).subscribe(data => {
      callBack(data);
    });
  }

  /**
   * 删除品牌
   * @param id
   * @param callBack
   */
  public deleteBrand(id: number, callBack:any) {
    this.http.get(environment.baseUrl + 'goodsBrand/delete?id=' + id ).subscribe(data => {
      callBack(data);
    });
  }

  /**
   * 获取商品列表
   * @param params
   * @param callBack
   */
  public getListGoods(params: object, callBack:any) {
    this.http.get(environment.baseUrl + 'goods/getListGoods?' + ObjectData.objectByString(params)).subscribe(data => {
      callBack(data);
    });
  }

  /**
   * 编辑商品信息
   * @param params
   * @param callBack
   */
  public editGoodsMsg(params: object, callBack:any) {
    this.http.post(environment.baseUrl + 'goods/editGoodsMsg', params).subscribe(data => {
      callBack(data);
    });
  }

  /**
   * 编辑商品规格信息
   * @param params
   * @param callBack
   */
  public editGoodsSpecs(params: object, callBack:any) {
    this.http.post(environment.baseUrl + 'goods/editGoodsSpecs', params).subscribe(data => {
      callBack(data);
    });
  }

  /**
   * 获取商品规格列表
   * @param params
   * @param callBack
   */
  public getGoodsSpecsList(params: object, callBack:any) {
    this.http.get(environment.baseUrl + 'goods/getGoodsSpecsList?' + ObjectData.objectByString(params)).subscribe(data => {
      callBack(data);
    });
  }

  /**
   * 删除商品
   * @param id
   * @param callBack
   */
  public deleteGoodsMsg(id: number, callBack:any) {
    this.http.get(environment.baseUrl + 'goods/deleteGoodsMsg?id=' + id ).subscribe(data => {
      callBack(data);
    });
  }

  /**
   * 删除商品规格
   * @param id
   * @param callBack
   */
  public deleteGoodsSpecs(id: number, callBack:any) {
    this.http.get(environment.baseUrl + 'goods/deleteGoodsSpecs?id=' + id ).subscribe(data => {
      callBack(data);
    });
  }

  /**
   * 获取全部上线中的商品规格
   * @param callBack
   */
  public getGoodsSpecsListAll(callBack:any) {
    this.http.get(environment.baseUrl + 'goods/getGoodsSpecsListAll?time=' + new Date().getTime()).subscribe(data => {
      callBack(data);
    });
  }

  /**
   * 商品审批
   * @param params
   * @param callBack
   */
  public goodsAudit(params: object, callBack:any) {
    this.http.get(environment.baseUrl + 'goods/goodsAudit?' + ObjectData.objectByString(params)).subscribe(data => {
      callBack(data);
    });
  }


}
